%==============================================================================
%
% Created by Tobias Löw
% RLIpaper 1.0.0
% 2022-01-10
%
%==============================================================================
\ProvidesClass{RLIpaper}[2022/01/10]

\newif\if@IEEE\@IEEEfalse
\newif\if@Springer\@Springerfalse
\newif\if@Frontiersin\@Frontiersinfalse
\newif\if@IJRR\@IJRRfalse

\DeclareOption{TRO}{
    \@IEEEtrue
    \PassOptionsToClass{letterpaper,10pt,journal,twoside}{IEEEtran}
}

\DeclareOption{IROS}{
    \@IEEEtrue
    \PassOptionsToClass{letterpaper,10pt,conference}{IEEEtran}
}

\DeclareOption{Springer}{
    \@Springertrue
    \PassOptionsToClass{}{birkjour}
}

\DeclareOption{Frontiersin}{
    \@Frontiersintrue
    \PassOptionsToClass{}{FrontiersinHarvard}
}

\DeclareOption{IJRR}{
    \@IJRRtrue
    \PassOptionsToClass{Afour,times}{sagej}
}

\ProcessOptions \relax

\if@IEEE
    \LoadClass[]{IEEEtran}

    \newcommand{\keywords}[1]{\begin{IEEEkeywords}#1\end{IEEEkeywords}}
    \newcommand{\affilationsymbol}[1]{\IEEEauthorrefmark{#1}}
    \newcommand{\affiliation}[1]{\thanks{#1}}
\else
\if@Springer
\LoadClass[]{birkjour}
\else
\if@Frontiersin
\LoadClass[]{FrontiersinHarvard}
\else
\if@IJRR
\LoadClass[]{sagej}
\setcounter{secnumdepth}{3}
\@ifundefined{chapter}{\def\thebibliography#1{\section*{\refname}\list
  {\relax}{\setlength{\labelsep}{0em}
        \setlength{\itemindent}{-\bibhang}
        \setlength{\leftmargin}{\bibhang}
        \setlength{\itemsep}{0pt}
        \parsep 0pt}%AS
    \def\newblock{\hskip .11em plus .33em minus .07em}
    \sloppy\clubpenalty4000\widowpenalty4000
    \sfcode`\.=1000\relax}}%
\fi
\fi
\fi
\fi

% bold math symbols
\RequirePackage{bm}

\RequirePackage{graphicx}
\RequirePackage{xcolor}

\usepackage[bookmarks=true,hidelinks]{hyperref} 
\usepackage[T1]{fontenc}

\RequirePackage{amsmath}

\RequirePackage{robot_maths}

\RequirePackage[
    backend=biber,
    isbn=false,
    url=false,
    % doi=false,
    eprint=false,
    style=ieee
]{biblatex}

\AtNextBibliography{\footnotesize}

\RequirePackage{subcaption}

\RequirePackage{tikz}
\tikzset{
    diagonal fill/.style 2 args={fill=#2, path picture={
    \fill[#1, sharp corners] (path picture bounding box.south west) -|
                             (path picture bounding box.north east) -- cycle;}},
    reversed diagonal fill/.style 2 args={fill=#2, path picture={
    \fill[#1, sharp corners] (path picture bounding box.north west) |- 
                             (path picture bounding box.south east) -- cycle;}}
}
\RequirePackage{tikzscale}

\RequirePackage{tabularx}
    % \newcolumntype{D}{>{$}l<{$}}                            % ganze Spalte im Mathe-Modus
    %                                                         % \tabular{>\displaystyle}D} um ganze Spalte in displaystyle
    % \newcolumntype{P}[1]{>{\centering\arraybackslash}p{#1}} % horizontale zentrierung in Tabellen. benutze wie p{}
    % \newcolumntype{M}[1]{>{\centering\arraybackslash}m{#1}} % horizontale zentrierung in Tabellen. benutze wie m{}
    % \newcolumntype{B}[1]{>{\centering\arraybackslash}b{#1}} % horizontale zentrierung in Tabellen. benutze wie b{}
    \newcolumntype{Z}{>{\centering\arraybackslash}X}        % X-Spalte in tabularx horizontal zentrieren
    % \newcolumntype{C}{>{\columncolor{lightgray}}Z}            % farbige Spalte
    % \newcolumntype{N}{@{}m{0pt}@{}}                            % muss eingefügt werden, eine Zeilenhöhe definiert werden soll
    %                                                         % {llN}
    %                                                         % bla & bla &\[20pt]
    %                                                         % rechtsbundig mit \hfill
    % \newcolumntype{g}{>{\columncolor{Variablen}}l}            % graue Spalte zentriert
    % \newcolumntype{h}{>{\columncolor{Variablen}}c}            % graue Spalte zentriert
    % \newcolumntype{i}{>{\columncolor{Variablen}}r}            % graue Spalte zentriert
    % \newcolumntype{G}{>{\columncolor{Variablen}}X}            % graue X-Spalte in tabularx links-bündig
    % \newcolumntype{H}{>{\columncolor{Variablen}}Z}            % graue X-Spalte in tabularx horizontal zentrieren

\RequirePackage[lined,ruled]{algorithm2e}

\RequirePackage{listings}
\lstset{
    language            = C++,
    showspaces          = false,
    showtabs            = false,
    breaklines          = true,
    showstringspaces    = false,
    breakatwhitespace   = false,
    escapeinside        = {(*@}{@*)},
    commentstyle        = \color{gray},
    keywordstyle        = \color{orange}\bfseries,
    stringstyle         = \color{red},
    basicstyle          = \tiny\ttfamily\color{black},
    backgroundcolor     = \color{lightgray!20!white},
    xleftmargin         = 0.0\linewidth,
    xrightmargin        = 0.0\linewidth
}

\lstset{
    emph={constexpr,requires},
    emphstyle={\color{green}\bfseries},
    emph={[2]Eigen},
    emphstyle={[2]\color{DarkGreen}\bfseries},
    emph={[3]Matrix,Multivector,Expression,Result,OuterProduct,Tool,Target,SandwichProduct,SingleManipulatorTarget,Motor,VectorX},
    emphstyle={[3]\color{LightBlue}\bfseries},
    emph={[4]vector,getError,getEEMotor,apply,getJacobian,transpose,getEEAnalyticJacobian,reverse,col,getValue,getGradient},
    emphstyle={[4]\color{DarkBlue}},
}

\definecolor{LightBlue}{RGB}{155,200,235}
\definecolor{DarkBlue}{RGB}{30,50,235}
\definecolor{DarkGreen}{RGB}{50,235,200}
\definecolor{CodeBackground}{RGB}{80,80,80}

\newcommand\addgrant[1]{%
  \begingroup
  \renewcommand\thefootnote{}\footnote{#1}%
  \addtocounter{footnote}{-1}%
  \endgroup
}